@@ -1,19 +1,25 @@
-import os
+
 import unittest
 import yaml
 
-from vot.workspace import Workspace, NullStorage
+from vot.workspace import NullStorage
 from vot.stack import Stack, list_integrated_stacks, resolve_stack
 
 class NoWorkspace:
+    """Empty workspace, does not save anything
+    """
 
     @property
     def storage(self):
         return NullStorage()
 
 class TestStacks(unittest.TestCase):
+    """Tests for the experiment stack utilities
+    """
 
     def test_stacks(self):
+        """Test loading integrated stacks
+        """
        
         stacks = list_integrated_stacks()
         for stack_name in stacks:
